

x0 = 0.1;

maxIter = 100;
tolerance = 1e-14;


%% solve x = (x^3 + 2)/7 by fixpoint method
x_FP1 = x0;
for iter = 1:maxIter
    x_new = (x_FP1^3 + 2)/7;
    if abs(x_new - x_FP1) < tolerance
        break;
    end
    x_FP1 = x_new;
end
fprintf('Fixpoint iteration 1 converged after %d iterations to x = %f, f(x) = %e\n', ...
    iter, x_FP1, x_FP1^3 - 7*x_FP1 + 2);

%% solve x = (7x-2)^(1/3) by fixpoint method
x_FP2 = x0;
for iter = 1:maxIter
    x_new = (7*x_FP2 - 2)^(1/3);
    if abs(x_new - x_FP2) < tolerance
        break;
    end
    x_FP2 = x_new;
end
fprintf('Fixpoint iteration 2 converged after %d iterations to x = %f, f(x) = %e\n', ...
    iter, x_FP2, x_FP2^3 - 7*x_FP2 + 2);

%% solve x = 2/(7-x^2) by fixpoint method
x_FP3 = x0;
for iter = 1:maxIter
    x_new = 2/(7-x_FP3^2);
    if abs(x_new - x_FP3) < tolerance
        break;
    end
    x_FP3 = x_new;
end
fprintf('Fixpoint iteration 3 converged after %d iterations to x = %f, f(x) = %e\n', ...
    iter, x_FP3, x_FP3^3 - 7*x_FP3 + 2);

%% solve x = sqrt(7 - 2/x) by fixpoint method
x_FP4 = x0;
for iter = 1:maxIter
    x_new = sqrt(7 - 2/x_FP4);
    if abs(x_new - x_FP4) < tolerance
        break;
    end
    x_FP4 = x_new;
end
fprintf('Fixpoint iteration 4 converged after %d iterations to x = %f, f(x) = %e\n', ...
    iter, x_FP4, x_FP4^3 - 7*x_FP4 + 2);

%% solve x^3 - 7x + 2 = 0 by Newton method
x_newton = x0;
for iter = 1:maxIter
    fx = x_newton^3 - 7*x_newton + 2;
    if abs(fx) < tolerance
        break;
    end
    Jx = 3*x_newton^2 - 7;
    x_newton = x_newton - fx/Jx;
end
fprintf('Newton method converged after %d iterations to x = %f, f(x) = %e\n', ...
    iter, x_newton, fx);

%% solve x^3 - 7x + 2 = 0 by secant method
x_secant = x0;
x_old = 0;
fx_old = 0;
for iter = 1:maxIter
    fx = x_secant^3 - 7*x_secant + 2;
    if abs(fx) < tolerance
        break;
    end
    Jx = (fx - fx_old)/(x_secant - x_old);
    x_old = x_secant;
    fx_old = fx;
    x_secant = x_secant - fx/Jx;
end
fprintf('Secant method converged after %d iterations to x = %f, f(x) = %e\n', ...
    iter, x_secant, fx);


